@@ -12,7 +12,7 @@ from datadog_lambda.extension import should_use_extension, flush_extension
 from datadog_lambda.cold_start import set_cold_start, is_cold_start
 from datadog_lambda.constants import XraySubsegment, TraceContextSource
 from datadog_lambda.metric import (
-    flush_thread_stats,
+    flush_stats,
     submit_invocations_metric,
     submit_errors_metric,
 )
@@ -95,6 +95,7 @@ class _LambdaDecorator(object):
             self.function_name = os.environ.get("AWS_LAMBDA_FUNCTION_NAME", "function")
             self.extractor_env = os.environ.get("DD_TRACE_EXTRACTOR", None)
             self.trace_extractor = None
+            self.span = None
 
             if self.extractor_env:
                 extractor_parts = self.extractor_env.rsplit(".", 1)
@@ -146,7 +147,6 @@ class _LambdaDecorator(object):
                     dd_context, XraySubsegment.TRACE_KEY
                 )
 
-            self.span = None
             if dd_tracing_enabled:
                 set_dd_trace_py_root(trace_context_source, self.merge_xray_traces)
                 self.span = create_function_execution_span(
@@ -177,7 +177,7 @@ class _LambdaDecorator(object):
                 )
 
             if not self.flush_to_log or should_use_extension:
-                flush_thread_stats()
+                flush_stats()
             if should_use_extension:
                 flush_extension()
 
